:mod:`extensible` --- Customizable payload
==========================================

This module contains several classes for working with network addresses. 

.. classoverview::
   :class:`~neo3.network.payloads.ExtensiblePayload`

The :class:`~neo3.network.payloads.ExtensiblePayload` is used in the consensus mechanism, as well can be used for sending
custom messages (i.e. in a plugin).


.. autoclass:: neo3.network.payloads.ExtensiblePayload
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
